===============
django-intranet
===============

Intranet made easy.


Abstract
========

``django-intranet`` is the minimal codebase to create fast enterprise
management applications.

Based on Django-1.4 you start a project, add ``intranet`` and the
other module you want to use.

That's it, you are ready to go with your intranet.


Documentation
=============

See ``docs/`` folder for detailed documentation.

Read it online at : http://django-intranet.readthedocs.org/


Quick start
===========

Create a project folder and enter-it ::

    $ pip install django-intranet South
    $ django-admin.py startproject myintranet


Configure the database and add intranet and south to you INSTALLED_APPS.

::

    $ python manage.py syncdb --migrate

Now you can install one of the contrib module or your own.


Permissions
===========

3 ways of defining a permission :

  - Using `django.contrib.auth permission system` of Model
  - Using an instance method that will take a user as a parameter
  - Using `django-guardian`_ for user configuration per-object permission

.. _`django-guardian`: http://django-guardian.readthedocs.org
